@@ -28,12 +28,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // Qt
 #include <QEventLoop>
 #include <QItemSelectionModel>
-
-// KDE
 #include <QDebug>
-#include <KDirLister>
 #include <QTest>
 
+// KF
+#include <KDirLister>
+
 using namespace Gwenview;
 using namespace TestUtils;
 
@@ -58,7 +58,7 @@ void ContextManagerTest::testRemove()
 
     QCOMPARE(dirModel.rowCount(), 3);
 
-    ContextManager manager(&dirModel, 0);
+    ContextManager manager(&dirModel, nullptr);
     // Select second row
     manager.selectionModel()->setCurrentIndex(dirModel.index(1, 0), QItemSelectionModel::Select);
 
