@@ -21,18 +21,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Qt
 #include <QTimer>
+#include <QStandardPaths>
 
-// KDE
+// KF
+#include <kio_version.h>
 #include <KIO/StatJob>
 #include <KIO/DeleteJob>
 #include <KIO/MkdirJob>
 #include <KIO/FileCopyJob>
 #include <KJobWidgets>
-#include <QStandardPaths>
 
 QUrl setUpRemoteTestDir(const QString& testFile)
 {
-    QWidget* authWindow = 0;
+    QWidget* authWindow = nullptr;
     if (qEnvironmentVariableIsEmpty("GV_REMOTE_TESTS_BASE_URL")) {
         qWarning() << "Environment variable GV_REMOTE_TESTS_BASE_URL not set: remote tests disabled";
         return QUrl();
@@ -42,7 +43,11 @@ QUrl setUpRemoteTestDir(const QString& testFile)
     baseUrl = baseUrl.adjusted(QUrl::StripTrailingSlash);
     baseUrl.setPath(baseUrl.path() + "/gwenview-remote-tests");
 
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
+    auto* statJob = KIO::statDetails(baseUrl, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
+#else
     KIO::StatJob *statJob = KIO::stat(baseUrl, KIO::StatJob::DestinationSide, 0);
+#endif
     KJobWidgets::setWindow(statJob, authWindow);
 
     if (statJob->exec()) {
@@ -85,7 +90,7 @@ void waitForDeferredDeletes()
 {
     while (QCoreApplication::hasPendingEvents()) {
         QCoreApplication::sendPostedEvents();
-        QCoreApplication::sendPostedEvents(0, QEvent::DeferredDelete);
+        QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
         QCoreApplication::processEvents();
     }
 }
